@@ -385,6 +385,8 @@ namespace mamba
                               std::vector<std::string>& source);
 
             static T deserialize(const std::string& value);
+
+            static bool is_sequence();
         };
 
         template <class T>
@@ -401,6 +403,8 @@ namespace mamba
                               std::vector<std::string>& source);
 
             static std::vector<T> deserialize(const std::string& value);
+
+            static bool is_sequence();
         };
 
         template <class T>
@@ -438,6 +442,12 @@ namespace mamba
             }
         }
 
+        template <class T>
+        bool Source<T>::is_sequence()
+        {
+            return false;
+        }
+
         template <class T>
         void Source<std::vector<T>>::merge(const std::map<std::string, std::vector<T>>& values,
                                            const std::vector<std::string>& sources,
@@ -468,6 +478,12 @@ namespace mamba
         {
             return YAML::Load("[" + value + "]").as<std::vector<T>>();
         }
+
+        template <class T>
+        bool Source<std::vector<T>>::is_sequence()
+        {
+            return true;
+        }
     }
 
 
@@ -592,6 +608,10 @@ namespace mamba
         self_type& compute(const int options = 0,
                            const ConfigurationLevel& level = ConfigurationLevel::kFile);
 
+        bool is_valid_serialization(const std::string& value) const;
+
+        bool is_sequence() const;
+
         void reset_compute_counter();
 
         void lock();
@@ -813,6 +833,26 @@ namespace mamba
         return *this;
     }
 
+    template <class T>
+    bool Configurable<T>::is_valid_serialization(const std::string& value) const
+    {
+        try
+        {
+            detail::Source<T>::deserialize(value);
+            return true;
+        }
+        catch (...)
+        {
+            return false;
+        }
+    }
+
+    template <class T>
+    bool Configurable<T>::is_sequence() const
+    {
+        return detail::Source<T>::is_sequence();
+    }
+
     template <class T>
     void Configurable<T>::lock()
     {
@@ -1010,6 +1050,10 @@ namespace mamba
 
             virtual bool has_single_op_lifetime() const = 0;
 
+            virtual bool is_valid_serialization(const std::string& value) const = 0;
+
+            virtual bool is_sequence() const = 0;
+
             virtual bool locked() = 0;
 
             virtual void reset_compute_counter() = 0;
@@ -1159,6 +1203,16 @@ namespace mamba
                 return p_wrapped->locked();
             }
 
+            bool is_valid_serialization(const std::string& value) const
+            {
+                return p_wrapped->is_valid_serialization(value);
+            }
+
+            bool is_sequence() const
+            {
+                return p_wrapped->is_sequence();
+            }
+
             void reset_compute_counter()
             {
                 p_wrapped->reset_compute_counter();
@@ -1443,6 +1497,16 @@ namespace mamba
             return p_impl->locked();
         }
 
+        bool is_valid_serialization(const std::string& value) const
+        {
+            return p_impl->is_valid_serialization(value);
+        }
+
+        bool is_sequence() const
+        {
+            return p_impl->is_sequence();
+        }
+
         self_type& set_rc_yaml_value(const YAML::Node& value, const std::string& source)
         {
             p_impl->set_rc_yaml_value(value, source);
